@@ -2,12 +2,13 @@ package Parse::RecDescent::FAQ;
 
 use vars qw($VERSION);
 
-
-our $VERSION = '6.0.a';
+$VERSION = '6.0.i';
 
 1;
+
 __END__
 
+
 =head1 NAME
 
 Parse::RecDescent::FAQ - the official, authorized FAQ for Parse::RecDescent. 
@@ -61,6 +62,22 @@ take advantage of the follow variables:
 How do I match the line numbers with the actual contents of my
 script?
 
+=head3 Solution 1
+
+(from Holger Helmuth)
+
+A possible solution is to put anything more complicated than a trivial
+statement into a subroutine outside of the parser. To call it you have
+to qualify it with the package name.
+
+Without this (maybe trivial?) method I probably would have given up on
+P:RD on my last project. Disadvantage is that the code is distributed
+into two locations and there should be a speed penality too, but it was
+definitely worth it.
+
+
+=head3 Solution 2
+
 At present, you can't (but that's on the ToDo list).
 Setting C<$::RD_TRACE> can be useful though:
 
@@ -320,9 +337,9 @@ If the 1st production of mysubrule has committed, then
 myrule should fail.  It doesn't seem to.  If this is
 not a bug, how do I get this behavior?
 
-=over 4
 
-=item * Answer by Damian
+
+=head3 Answer by Damian
 
 The optional nature of the reference to mysubrule(?)
 means that, when the subrule fails (whether committed or not)
@@ -349,7 +366,7 @@ or
 or whatever addition confirms that there really wasn't anything else
 after 'stuff'.
 
-=item * Now that you think you know the answer...
+=head3 Now that you think you know the answer...
 
 That answer is partially wrong, as was pointed out by Marcel Grunaer.
 In this phrase:
@@ -361,7 +378,7 @@ fails otherwise, presumably because of the negative lookahead:
 
   myrule: 'stuff' mysubrule(?) ...!ID { 1 }
 
-Marcel went on to point out an optimization:
+=head4 Marcel went on to point out an optimization:
 
 another option would be the use of a rulevar:
 
@@ -376,10 +393,6 @@ lookahead, and the method works over several levels of subrules
 as well.
 
 
-=back
-
-
-
 =head1 IGNORABLE TOKENS 
 
 =head2 Removing C comments
@@ -643,10 +656,24 @@ So if you would like to state the test in the positive, then do this:
 
 =back
 
+=head1 Parsing Quotes within .... Quotes!
+
+A recent node on Perlmonks 
+L<http://perlmonks.org/?node_id=665986|http://perlmonks.org/?node_id=665986>
+had a question on how to parse:
+
+    A statement "with a quoted ';'" ;
+
+The best answer is the C<perl_quotelike> section in the offical docs for
+L<Parse::RecDescent|Parse::RecDescent>. An earlir node on Perlmonks:
+L<http://perlmonks.org/?node_id=485933|http://perlmonks.org/?node_id=485933> 
+covers the use of C<perl_quotelike> in detail.
+
+
 =head1 MODULAR / GENERATIVE / CREATIVE / HAIRY PARSING
 
 
-Be sure to see the example see the RESOURCES section at the end
+Be sure to see the example see the L<"RESOURCES"> section at the end
 for even more nosebleed parsing examples.
 
 =head2 Subrule matches N times, where N is parsed on the fly
@@ -1496,6 +1523,17 @@ it occurred at.
 
 =head1 OTHER Parse::RecDescent QUESTIONS
 
+=head2 How to get the old perl.com article to work?
+
+Jethro of Perlmonks answers:
+
+L<http://perlmonks.org/?node_id=786132>
+
+
+The problem is that C<return()> finishes parsing.
+
+Parse::RecDescent works with a variable C<$return> to give back results from subrules to parent rules. If you change the three occurences of C<return> inside the grammar (but not inside the sub 'expression') to C<< $return= >> the parser works.
+
 
 =head2 Matching line continuation characters
 
@@ -1839,38 +1877,17 @@ something interesting that I can't explain to myself.
 
 Here is my script:
 
------- Start Script ------
-use strict;
-use warnings;
-
-$::RD_TRACE = 1;
-
-use Parse::RecDescent;
-
-my $grammar = q{
-
-   input:  number(s) { $return = $item{ number } } | <error>
-
-   number: <skip: '\.*'> /\d+/ 
-
-};
-
-my $parser = new Parse::RecDescent($grammar);
-
-my $test_string = qq{1.2.3.5.8};
-
-print join( "\n", @{ $parser -> input( $test_string ) } );
------- End Script ------
+Program fragment delivered error ``couldnt open file : No such file or directory at ./tt.pl line 18, <F> line 332.''
 
 This script works great. However, if I change the value of the skip
 directive so that it uses double quotes instead of single quotes:
 
-<skip: "\.*">
+    <skip: "\.*">
 
 the grammar fails to parse the input. However, if I put square
 brackets around the escaped dot:
 
-<skip: "[\.]*">
+    <skip: "[\.]*">
 
 the grammar starts working again:
 
@@ -2313,6 +2330,26 @@ Ok, so he hasn't named it yet. It's available online for free!
 You still need to know when to use C</.*/> or C</.+/> or C</[^x]*/>
 
 
+=head1 Perlmonks Nodes
+
+Basically the number of posts on Perlmonks about Parse::RecDescent are
+growing faster than I have time to study them closely and categorize
+them. But it is important that you have rapid access to them instead
+of slogging through Super Search or a google site search, so here you
+go:
+
+=over 4
+
+=item * Pro teaches amateur
+
+L<http://perlmonks.org/?node_id=674283|http://perlmonks.org/?node_id=674283>
+
+Perlmonk Ikegami gives a wonderful set of best practices for
+Recdescent usage.
+
+
+=back
+
 =head1 RESOURCES
 
 =head2 Web Links
@@ -2481,6 +2518,23 @@ the same. L<Scalar::Listify|Scalar::Listify> facilitates this process.
 
 =head2 Practical Parser Examples
 
+=head3 DBFeeder / Data::Generate - database test data generation tool
+
+L<http://dbfeeder.sourceforge.net/|http://dbfeeder.sourceforge.net/>
+is a a powerful data generation tool. Internally, it uses
+L<Data::Generate|Data::Generate> to parse "inverted regular expressions" 
+using Parse::RecDescent.
+
+
+=head4 Tangential new directions
+
+In a recent perlmonks thread:
+L<http://perlmonks.org/?node_id=672163|http://perlmonks.org/?node_id=672163> 
+the author of DBFeeder (Davide Conti) discusses SQL parsing with 
+Parse::RecDescent (among other tools). This technology is not currently
+a part of DBFeeder and Data::Generate, but an avenue he is exploring.
+
+
 =head3 Article comparing Gene Parsing with PRD and other approaches
 
 "The Making of Entrez Gene parsers in Perl using
@@ -2573,11 +2627,11 @@ have used Lex and Yacc. Parse::RecDescent is a top-down parser.
 
 =head3 Parse::Earley
 
-L<search.cpan.org/dist/Parse-Earley>
+L<Parse::Earley>
 
 =head3 Perl6::Rules
 
-L<search.cpan.org/dist/Perl6-Rules>
+L<Perl6::Rules>
 
 =head3 perl-byacc
 
@@ -2601,7 +2655,7 @@ prd.
 The author of Parse::RecDescent is Damian Conway. 
 
 The author of Parse::RecDescent::FAQ is Terrence Brannon <tbone@cpan.org>. 
-L<http://www.metaperl.com>
+L<http://www.metaperl.org>
 
 The (unwitting) contributors to this FAQ
 
@@ -2652,6 +2706,10 @@ Conveniently available via NNTP at:
 
 =back
 
+=head1 FAQ repo
+
+L<http://github.com/metaperl/Parse--RecDescent--FAQ/tree/master>
+
 
 
 =cut
